import { SarifApiResponse } from '../lib/apiClient'
import { cn } from '../lib/utils'

const people = [
    {
        name: 'Lindsay Walton',
        title: 'Front-end Developer',
        email: 'lindsay.walton@example.com',
        role: 'Member',
    },
    // More people...
]
interface Props {
    currentScan: SarifApiResponse
}

export default function ResultTable({ currentScan }: Props) {
    return (
        <div className="">
            {currentScan?.runs[0].properties.badges
                .sort((a, b) => a.badgeId.localeCompare(b.badgeId))
                .map((badge) => (
                    <div
                        key={`${badge.badgeId}-${badge.badgeLevel}`}
                        className="mt-8 rounded-lg bg-gray-100 p-10"
                    >
                        <details className="">
                            <summary className="relative text-lg font-medium text-gray-900">
                                Details on: {badge.badgeId} {badge.badgeLevel}
                                <span className="ml-2 inline-block">
                                    <span className="relative flex size-3">
                                        <span
                                            className={cn(
                                                'absolute inline-flex h-full w-full animate-ping rounded-full opacity-75',
                                                badge.badgeGranted
                                                    ? 'bg-green-400'
                                                    : 'bg-red-400',
                                            )}
                                        ></span>
                                        <span
                                            className={cn(
                                                'relative inline-flex size-3 rounded-full',
                                                badge.badgeGranted
                                                    ? 'bg-green-400'
                                                    : 'bg-red-400',
                                            )}
                                        ></span>
                                    </span>
                                </span>
                            </summary>
                            <div className="mt-8">
                                <div className="-mx-4 -my-2 overflow-x-auto sm:-mx-6 lg:-mx-8">
                                    <div className="inline-block min-w-full py-2 align-middle">
                                        <table className="min-w-full divide-y divide-gray-300">
                                            <thead>
                                                <tr className="grid grid-cols-6">
                                                    <th
                                                        scope="col"
                                                        className="col-span-1 py-3.5 pl-4 pr-3 text-left text-sm font-semibold text-gray-900 sm:pl-6 lg:pl-8"
                                                    >
                                                        Check
                                                    </th>
                                                    <th
                                                        scope="col"
                                                        className="col-span-1 px-3 py-3.5 text-left text-sm font-semibold text-gray-900"
                                                    >
                                                        Status
                                                    </th>
                                                    <th
                                                        scope="col"
                                                        className="col-span-2 px-3 py-3.5 text-left text-sm font-semibold text-gray-900"
                                                    >
                                                        Description
                                                    </th>
                                                    <th
                                                        scope="col"
                                                        className="col-span-2 px-3 py-3.5 text-left text-sm font-semibold text-gray-900"
                                                    >
                                                        Evidence
                                                    </th>
                                                </tr>
                                            </thead>
                                            <tbody className="divide-y divide-gray-200">
                                                {badge.badgeExplanation.criteria.map(
                                                    (criteria) => (
                                                        <tr
                                                            key={`${badge.badgeId}-${badge.badgeLevel}-${criteria.ruleId}`}
                                                            className="grid grid-cols-6"
                                                        >
                                                            <td className="col-span-1 whitespace-nowrap py-4 pl-4 pr-3 text-sm font-medium text-gray-900 sm:pl-6 lg:pl-8">
                                                                {
                                                                    criteria.ruleId.split(
                                                                        ':',
                                                                    )[0]
                                                                }
                                                            </td>
                                                            <td className="col-span-1 whitespace-nowrap px-3 py-4 text-sm text-gray-500">
                                                                <div className="flex items-center justify-end gap-x-2 sm:justify-start">
                                                                    <span className="relative flex size-2">
                                                                        <span
                                                                            className={cn(
                                                                                'absolute inline-flex h-full w-full animate-ping rounded-full opacity-75',
                                                                                criteria.status ===
                                                                                    'pass'
                                                                                    ? 'bg-green-400'
                                                                                    : criteria.status ===
                                                                                        'open'
                                                                                      ? 'bg-gray-400'
                                                                                      : 'bg-red-400',
                                                                            )}
                                                                        ></span>
                                                                        <span
                                                                            className={cn(
                                                                                'relative inline-flex size-2 rounded-full',
                                                                                criteria.status ===
                                                                                    'pass'
                                                                                    ? 'bg-green-400'
                                                                                    : criteria.status ===
                                                                                        'open'
                                                                                      ? 'bg-gray-400'
                                                                                      : 'bg-red-400',
                                                                            )}
                                                                        ></span>
                                                                    </span>
                                                                    <div className="hidden text-black sm:block">
                                                                        {
                                                                            criteria.status
                                                                        }
                                                                    </div>
                                                                </div>
                                                            </td>
                                                            <td className="col-span-2 px-3 py-4 text-sm text-gray-500">
                                                                {
                                                                    criteria.description
                                                                }
                                                            </td>
                                                            <td className="col-span-2 px-3 py-4 text-sm text-gray-500">
                                                                {
                                                                    criteria.evidence
                                                                }
                                                            </td>
                                                        </tr>
                                                    ),
                                                )}
                                            </tbody>
                                        </table>
                                    </div>
                                </div>
                            </div>
                        </details>
                    </div>
                ))}
        </div>
    )
}
